@@ -546,11 +546,39 @@ try:
         
     class CPLEX_DLL(LpSolver):
         """The CPLEX LP/MIP solver (via a Dynamic library DLL - windows or SO - Linux)"""
-        def __init__(self, mip = 1, msg = 1, timeLimit = -1, debug = False):
+        EPGAP = 2009
+        def __init__(self, mip = 1, msg = 1, timeLimit = -1,
+                       epgap = None, logfile = None, debug = False):
             LpSolver.__init__(self, mip, msg)
             self.timeLimit = timeLimit
             self.debug = debug
             self.grabLicence()
+            if epgap is not None:
+                self.changeEpgap(epgap)
+            if logfile is not None:
+                self.setlogfile(logfile)
+            else:
+                self.logfile = None
+
+        def setlogfile(self, filename):
+            """
+            sets the logfile for cplex output
+            """
+            CplexDll.CPXfopen.argtypes = [ctypes.c_char_p, 
+                                          ctypes.c_char_p]
+            CplexDll.CPXfopen.restype = ctypes.c_void_p
+            self.logfilep = CplexDll.CPXfopen(filename, "w")
+            CplexDll.CPXsetlogfile.argtypes = [ctypes.c_void_p, 
+                                          ctypes.c_void_p] 
+            CplexDll.CPXsetlogfile(self.env, self.logfilep)
+        
+        def changeEpgap(self, epgap = 10**-4):
+            """
+            Change cplex solver integer bound gap tolerence
+            """
+            CplexDll.CPXsetdblparam.argtypes = [ctypes.c_void_p, ctypes.c_int, 
+                                                ctypes.c_double]
+            CplexDll.CPXsetdblparam(self.env,CPLEX_DLL.EPGAP,epgap)
 
         def findSolutionValues(self, lp, numcols, numrows):
             byref = ctypes.byref
